@@ -1,15 +1,9 @@
+import argparse
+import io
 import logging
-
 import os
 import sys
-import argparse
-
-try:
-    # Needed for Python < 3.3, works up to 3.8
-    import xml.etree.cElementTree as etree
-except ImportError:
-    # Python 3.9 onwards
-    import xml.etree.ElementTree as etree
+import xml.etree.ElementTree as etree
 
 from diff_cover import DESCRIPTION, VERSION
 from diff_cover.diff_reporter import GitDiffReporter
@@ -17,9 +11,9 @@ from diff_cover.git_diff import GitDiffTool
 from diff_cover.git_path import GitPathTool
 from diff_cover.report_generator import (
     HtmlReportGenerator,
-    StringReportGenerator,
     JsonReportGenerator,
     MarkdownReportGenerator,
+    StringReportGenerator,
 )
 from diff_cover.violationsreporters.violations_reporter import XmlCoverageReporter
 
@@ -40,6 +34,7 @@ COVERAGE_XML_HELP = "XML coverage report"
 DIFF_RANGE_NOTATION_HELP = (
     "Git diff range notation to use when comparing branches, defaults to '...'"
 )
+QUIET_HELP = "Only print errors and failures"
 
 LOGGER = logging.getLogger(__name__)
 
@@ -152,6 +147,8 @@ def parse_coverage_args(argv):
         help=IGNORE_WHITESPACE,
     )
 
+    parser.add_argument("-q", "--quiet", action="store_true", help=QUIET_HELP)
+
     return vars(parser.parse_args(argv))
 
 
@@ -168,6 +165,7 @@ def generate_coverage_report(
     src_roots=None,
     diff_range_notation=None,
     ignore_whitespace=False,
+    quiet=False,
 ):
     """
     Generate the diff coverage report, using kwargs from `parse_args()`.
@@ -205,8 +203,9 @@ def generate_coverage_report(
         with open(markdown_report, "wb") as output_file:
             reporter.generate_report(output_file)
 
+    # Generate the report for stdout
     reporter = StringReportGenerator(coverage, diff)
-    output_file = sys.stdout.buffer
+    output_file = io.BytesIO() if quiet else sys.stdout.buffer
 
     # Generate the report
     reporter.generate_report(output_file)
@@ -221,10 +220,13 @@ def main(argv=None, directory=None):
     1 is an error
     0 is successful run
     """
-    logging.basicConfig(format="%(message)s")
-
     argv = argv or sys.argv
     arg_dict = parse_coverage_args(argv[1:])
+
+    quiet = arg_dict["quiet"]
+    level = logging.ERROR if quiet else logging.WARNING
+    logging.basicConfig(format="%(message)s", level=level)
+
     GitPathTool.set_cwd(directory)
     fail_under = arg_dict.get("fail_under")
     percent_covered = generate_coverage_report(
@@ -240,6 +242,7 @@ def main(argv=None, directory=None):
         src_roots=arg_dict["src_roots"],
         diff_range_notation=arg_dict["diff_range_notation"],
         ignore_whitespace=arg_dict["ignore_whitespace"],
+        quiet=quiet,
     )
 
     if percent_covered >= fail_under:
